package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 25, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package plugin manages PSL protocol packages (install, load, publish).
InitPackage creates a new protocol package scaffold.
Install downloads and installs a protocol package from a URL or local path.
ListInstalled returns all installed plugin names.
PluginDir returns the default plugin directory (~/.psl/plugins/).
Uninstall removes an installed plugin.
type PackageManifest struct {
Name string `json:"name"`
Version string `json:"version"`
Description string `json:"description"`
Author string `json:"author"`
License string `json:"license"`
}
PackageManifest describes a PSL protocol package.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.